@@ -731,8 +731,8 @@ MONGOCTL_PARSER_DEF = {
             {
             "prog": "status",
             "group": "serverCommands",
-            "shortDescription" : "retrieve status of server or a cluster",
-            "description" : "Retrieves the status of a server or a cluster.",
+            "shortDescription" : "retrieve status of server",
+            "description" : "Retrieves the status of a server",
             "function": "mongoctl.mongoctl.status_command",
             "args":[
                     {   "name": "id",
@@ -771,8 +771,8 @@ MONGOCTL_PARSER_DEF = {
             {
             "prog": "list-servers",
             "group": "serverCommands",
-            "shortDescription" : "list all server configurations",
-            "description" : "List all server configurations.",
+            "shortDescription" : "show list of configured servers",
+            "description" : "Show list of configured servers.",
             "function": "mongoctl.mongoctl.list_servers_command"
         },
         #### show-server ####
@@ -952,6 +952,16 @@ MONGOCTL_PARSER_DEF = {
                     "nargs": 1,
                     "help": "database addresse or dbpath. Check docs for"
                             " more details."
+                },
+                    {
+                    "name": "useBestSecondary",
+                    "type" : "optional",
+                    "help": "Only for clusters. Dump from the best secondary "
+                            "(passive / least repl lag)",
+                    "cmd_arg": [
+                        "--use-best-secondary"
+                    ],
+                    "nargs": 0
                 },
                     {
                     "name": "username",
@@ -1082,7 +1092,7 @@ MONGOCTL_PARSER_DEF = {
             {
             "prog": "restore",
             "group": "clientCommands",
-            "shortDescription" : "Restore MongoDB (using mongorestore0",
+            "shortDescription" : "Restore MongoDB (using mongorestore)",
             "description" : "Runs a mongorestore from specified file or directory"
                             " to database address or dbpath. If a\n"
                             "cluster is specified command will restore against "
@@ -1339,8 +1349,8 @@ MONGOCTL_PARSER_DEF = {
             {
             "prog": "list-clusters",
             "group": "clusterCommands",
-            "shortDescription" : "list all cluster configurations",
-            "description" : "List all cluster configurations",
+            "shortDescription" : "show list of configured clusters",
+            "description" : "Show list of configured servers",
             "function": "mongoctl.mongoctl.list_clusters_command"
         },
 
